@@ -1,6 +1,3 @@
-from Crypto.Cipher import AES
-from Crypto.Util.Padding import pad, unpad
-from base64 import b64encode , urlsafe_b64decode
 from datetime import datetime
 from json import loads, dumps
 from random import randint
@@ -11,46 +8,12 @@ from pathlib import Path
 from urllib import request
 from mutagen.mp3 import MP3
 from time import sleep
+from .Encryption import Encryption
 
-__version__:str='1.4.4'
+__version__:str='1.5.0'
 __author__:str='Shayan Heidari'
 __copyright__:str='CopyRight 2022'
 
-class Encryption:
-    def __init__(self, auth,):
-        self.key = bytearray(self.secret(auth), "UTF-8")
-        self.iv = bytearray.fromhex('00000000000000000000000000000000')
-
-    def replaceCharAt(self, e, t, i):
-        return e[0:t] + i + e[t + len(i):]
-
-    def secret(self, e):
-        t = e[0:8]
-        i = e[8:16]
-        n = e[16:24] + t + e[24:32] + i
-        s = 0
-        while s < len(n):
-            e = n[s]
-            if e >= '0' and e <= '9':
-                t = chr((ord(e[0]) - ord('0') + 5) % 10 + ord('0'))
-                n = self.replaceCharAt(n, s, t)
-            else:
-                t = chr((ord(e[0]) - ord('a') + 9) % 26 + ord('a'))
-                n = self.replaceCharAt(n, s, t)
-            s += 1
-        return n
-
-    def encrypt(self, text):
-        raw = pad(text.encode('UTF-8'), AES.block_size)
-        aes = AES.new(self.key, AES.MODE_CBC, self.iv)
-        enc = aes.encrypt(raw)
-        return b64encode(enc).decode('UTF-8')
-
-    def decrypt(self, text):
-        aes = AES.new(self.key, AES.MODE_CBC, self.iv)
-        dec = aes.decrypt(urlsafe_b64decode(text.encode('UTF-8')))
-        return unpad(dec, AES.block_size).decode('UTF-8')
-
 class Clients:
 	web = { "app_name"    : "Main", "app_version" : "4.0.7", "platform"    : "Web", "package"     : "web.rubika.ir", "lang_code"   : "fa" }
 	android = { "app_name" : "Main", "app_version" : "2.9.8", "platform" : "Android", "package"     : "app.rbmain.a", "lang_code"   : "fa" }
@@ -66,22 +29,22 @@ class Bot:
 
 	def getChatsUpdate(self,):
 		return loads(self.enc.decrypt(loads(request.urlopen(request.Request('https://messengerg2c64.iranlms.ir/', data=dumps({"api_version":"5","auth": self.auth,"data_enc":self.enc.encrypt(dumps({
-					"method":"getChatsUpdates",
-					"input":{
-						"state":str(round(datetime.today().timestamp()) - 200),
-					},
-					"client": Clients.web
-				}))}).encode(), headers={'Content-Type': 'application/json'})).read()).get('data_enc'))).get('data').get('chats')
+			"method":"getChatsUpdates",
+			"input":{
+					"state":str(round(datetime.today().timestamp()) - 200),
+				},
+				"client": Clients.web
+			}))}).encode(), headers={'Content-Type': 'application/json'})).read()).get('data_enc'))).get('data').get('chats')
 
 	def sendChatActivity(self, object_guid, activity,):
 		return loads(self.enc.decrypt(loads(request.urlopen(request.Request('https://messengerg2c64.iranlms.ir/', data=dumps({"api_version":"5","auth": self.auth,"data_enc":self.enc.encrypt(dumps({
-					"method":"sendChatActivity",
-					"input":{
-						"activity": activity,
-						"object_guid": object_guid,
-					},
-					"client": Clients.web
-				}))}).encode(), headers={'Content-Type': 'application/json'})).read()).get('data_enc')))
+			"method":"sendChatActivity",
+			"input":{
+				"activity": activity,
+				"object_guid": object_guid,
+			},
+			"client": Clients.web
+		}))}).encode(), headers={'Content-Type': 'application/json'})).read()).get('data_enc')))
 
 	def getChats(self, start_id=None,):
 		return loads(self.enc.decrypt(loads(request.urlopen(request.Request('https://messengerg2c64.iranlms.ir/', data=dumps({"api_version":"5","auth": self.auth,"data_enc":self.enc.encrypt(dumps({
@@ -217,7 +180,7 @@ class Bot:
 					t = True
 				except:
 					t = False
-
+			
 			return j
 		else:
 			t = round(len(file_byte) / 131072 + 1)
@@ -243,7 +206,7 @@ class Bot:
 					j = k + 131072
 					j = round(j / 1024)
 					j2 = round(len(file_byte) / 1024)
-					print(str(j) + 'kb / ' + str(j2) + ' kb')
+					print(str(j) + 'kb / ' + str(j2) + ' kb')                
 				else:
 					k = i - 1
 					k = k * 131072
@@ -263,7 +226,7 @@ class Bot:
 						except:
 							t2 = False
 					j2 = round(len(file_byte) / 1024)
-					print(str(j2) + 'kb / ' + str(j2) + ' kb')
+					print(str(j2) + 'kb / ' + str(j2) + ' kb') 
 					return p
 
 	@staticmethod
@@ -377,11 +340,9 @@ class Bot:
 		#request with api v 4
 		return loads(self.enc.decrypt(loads(request.urlopen(request.Request('https://messengerg2c64.iranlms.ir/', data=dumps({"api_version":"4","auth": self.auth,"data_enc":self.enc.encrypt(dumps({
 					"method":"setGroupDefaultAccess",
-					"input":{
-						"access_list": access_list,
-						"group_guid": group_guid,
-					},
-					"client": Clients.web
+					"access_list": access_list,
+					"group_guid": group_guid,
+					"client": Clients.android
 				}))}).encode(), headers={'Content-Type': 'application/json'})).read()).get('data_enc')))
 
 	def getGroupLink(self, group_guid,):
@@ -391,11 +352,10 @@ class Bot:
 						"group_guid":group_guid,
 					},
 					"client": Clients.web
-				}))}).encode(), headers={'Content-Type': 'application/json'})).read()).get('data_enc')))
+				}))}).encode(), headers={'Content-Type': 'application/json'})).read()).get('data_enc'))).get('data').get('join_link')
 
 	def changeGroupLink(self, group_guid):
-		# request with api v 4
-		return loads(self.enc.decrypt(loads(request.urlopen(request.Request('https://messengerg2c64.iranlms.ir/', data=dumps({"api_version":"4","auth": self.auth,"data_enc":self.enc.encrypt(dumps({
+		return loads(self.enc.decrypt(loads(request.urlopen(request.Request('https://messengerg2c64.iranlms.ir/', data=dumps({"api_version":"5","auth": self.auth,"data_enc":self.enc.encrypt(dumps({
 					"method":"setGroupLink",
 					"input":{
 						"group_guid":group_guid,
@@ -404,8 +364,7 @@ class Bot:
 				}))}).encode(), headers={'Content-Type': 'application/json'})).read()).get('data_enc')))
 
 	def setGroupTimer(self, group_guid, time,):
-		# request with api v 4
-		return loads(self.enc.decrypt(loads(request.urlopen(request.Request('https://messengerg2c64.iranlms.ir/', data=dumps({"api_version":"4","auth": self.auth,"data_enc":self.enc.encrypt(dumps({
+		return loads(self.enc.decrypt(loads(request.urlopen(request.Request('https://messengerg2c64.iranlms.ir/', data=dumps({"api_version":"5","auth": self.auth,"data_enc":self.enc.encrypt(dumps({
 					"method":"editGroupInfo",
 					"input":{
 						"group_guid":group_guid,
